@@ -18,7 +18,7 @@
  */
 
 
-#undef LOCAL_DEBUG 
+#define LOCAL_DEBUG 
 #define DO_CLOCKING
 
 #include "../configure.h"
@@ -133,12 +133,28 @@ filter_desktop_entry_exec( const char *exec )
 	return clean_exec;
 }
 
+char *stripcpy_localized( char *ptr ) 
+{
+	int i = 0 ; 
+	static char default_locale[] = "us" ;
+	char *locale = MyArgs.locale[0]?MyArgs.locale:&default_locale[0] ; 
+	while( locale[i] != '.' && locale[i] != '\0'  && ptr[i] != ']') 
+	{
+		if( ptr[i] != locale[i] ) 
+			break;
+		++i ;
+	}
+	if((locale[i] == '.' || locale[i] == '\0') && ptr[i] == ']' )
+		return stripcpy(ptr+i+2) ;
+	return NULL ;
+}
+
 static void 
 parse_desktop_entry_line( ASDesktopEntry* de, char *ptr ) 
 {
 #define PARSE_ASDE_TYPE_VAL(val)	if(mystrncasecmp(ptr, #val, ASDE_KEYWORD_##val##_LEN) == 0){de->type = ASDE_Type##val; return;}					   			   				   
 #define PARSE_ASDE_STRING_VAL(val)	if(mystrncasecmp(ptr, #val "=", ASDE_KEYWORD_##val##_LEN+1) == 0){if( de->val ) free( de->val ) ; de->val = stripcpy(ptr+ASDE_KEYWORD_##val##_LEN+1); return;}					   
-#define PARSE_ASDE_FLAG_VAL(val)	if(mystrncasecmp(ptr, #val "=", ASDE_KEYWORD_##val##_LEN+1) == 0){char *tmp = stripcpy(ptr+ASDE_KEYWORD_##val##_LEN+1); if(mystrcasecmp(tmp, "true") == 0 ) set_flags(de->flags, ASDE_##val); free(tmp); return;}					   			   
+#define PARSE_ASDE_FLAG_VAL(val)	if(mystrncasecmp(ptr, #val "=", ASDE_KEYWORD_##val##_LEN+1) == 0){char *tmp = stripcpy(ptr+ASDE_KEYWORD_##val##_LEN+1); if( tmp[0] == '1' || mystrcasecmp(tmp, "true") == 0 ) set_flags(de->flags, ASDE_##val); free(tmp); return;}					   			   
 
 	if( ptr[0] == 'X' && ptr[1] == '-') 
 	{
@@ -154,9 +170,11 @@ parse_desktop_entry_line( ASDesktopEntry* de, char *ptr )
 			set_flags( de->flags, ASDE_KDE );
 		else if( mystrncasecmp( ptr, "GNOME-", 6 ) == 0 ) 
 			set_flags( de->flags, ASDE_GNOME );
-	}else if( mystrncasecmp( ptr, "Name[", 5 ) == 0 ) 
+	}else if( mystrncasecmp( ptr, "Name[", 5 ) == 0 && MyArgs.locale[0] == ptr[5] ) 
 	{
-		/* TODO */
+		char *val = stripcpy_localized(ptr+5); 
+		if( val ) 
+			set_string( &(de->Name_localized), val );
 	}else if( mystrncasecmp( ptr, "Type=", 5 ) == 0 ) 
 	{
 		ptr += 5 ;
@@ -165,9 +183,11 @@ parse_desktop_entry_line( ASDesktopEntry* de, char *ptr )
 		PARSE_ASDE_TYPE_VAL(Link)
 		PARSE_ASDE_TYPE_VAL(FSDevice)
 		PARSE_ASDE_TYPE_VAL(Directory)
-	}else if( mystrncasecmp( ptr, "Comment[", 8 ) == 0 ) 
+	}else if( mystrncasecmp( ptr, "Comment[", 8 ) == 0 && MyArgs.locale[0] == ptr[8] ) 
 	{
-		/* TODO */
+		char *val = stripcpy_localized(ptr+8); 
+		if( val ) 
+			set_string( &(de->Comment_localized), val );
 	}else if( mystrncasecmp( ptr, "Encoding=UTF-8", 14 ) == 0 ) 
 	{	
 		set_flags( de->flags, ASDE_EncodingUTF8 );
@@ -274,6 +294,7 @@ fix_desktop_entry( ASDesktopEntry *de, const char *default_category, const char
 		}	 
 		if( de->fulliconname == NULL ) 
 			de->fulliconname = find_file (de->Icon, icon_path, R_OK);
+		LOCAL_DEBUG_OUT( "icon %s has fullname %s", de->Icon, de->fulliconname?de->fulliconname:"(null)");
 	}	 
 	if( de->Exec ) 
 		de->clean_exec = filter_desktop_entry_exec( de->Exec );
@@ -485,7 +506,7 @@ DestroyCategories()
 	if( AfterStepCategories) destroy_category_tree( &AfterStepCategories); 	
 	if( KDECategories      ) destroy_category_tree( &KDECategories      ); 	
 	if( GNOMECategories    ) destroy_category_tree( &GNOMECategories    ); 	
-	if( SystemCategories   ) destroy_category_tree( &SystemCategories   ); 	
+	if( OtherCategories    ) destroy_category_tree( &OtherCategories   ); 	
 	if( CombinedCategories ) destroy_category_tree( &CombinedCategories ); 	
 #ifdef DEBUG_ALLOCS
 /*	print_unfreed_mem (); */
@@ -517,7 +538,7 @@ UpdateCategoriesCache()
 	save_category_tree_cache( AfterStepCategories,	AFTERSTEP_CACHE_FILE );  
 	save_category_tree_cache( KDECategories, 		KDE_CACHE_FILE );  
 	save_category_tree_cache( GNOMECategories, 		GNOME_CACHE_FILE );  
-	save_category_tree_cache( SystemCategories, 	SYSTEM_CACHE_FILE );  
+	save_category_tree_cache( OtherCategories, 		OTHER_CACHE_FILE );  
 }	 
 
 void 
@@ -530,7 +551,7 @@ ReloadCategories(Bool cached)
 	
     if( (configfile = make_session_file(Session, STANDARD_CATEGORIES_FILE, False )) != NULL )
 	{
-		StandardCategories = create_category_tree( "Default", configfile , NULL, 0, -1 );	 
+		StandardCategories = create_category_tree( "Default", configfile , Environment?Environment->pixmap_path:NULL, 0, -1 );	 
 		free( configfile );
 	}
 
@@ -544,8 +565,8 @@ ReloadCategories(Bool cached)
 		free( configfile );configfile = make_session_data_file(Session, False, 0, GNOME_CACHE_FILE, NULL );
  		GNOMECategories = create_category_tree( "GNOME", configfile, GNOME_ICONS_PATH, 0, -1 );	
 		free( configfile );
-		configfile = make_session_data_file(Session, False, 0, SYSTEM_CACHE_FILE, NULL );
- 		SystemCategories = create_category_tree( "SYSTEM", configfile, SYSTEM_ICONS_PATH, 0, -1 );	
+		configfile = make_session_data_file(Session, False, 0, OTHER_CACHE_FILE, NULL );
+ 		OtherCategories = create_category_tree( "OTHER", configfile, OTHER_ICONS_PATH, 0, -1 );	
 		free( configfile );
 	}else
 	{
@@ -558,7 +579,7 @@ ReloadCategories(Bool cached)
 		
 		KDECategories = create_category_tree( "KDE", KDE_APPS_PATH, KDE_ICONS_PATH, ASCT_OnlyKDE, -1 );	   
  		GNOMECategories = create_category_tree( "GNOME", GNOME_APPS_PATH, GNOME_ICONS_PATH, ASCT_OnlyGNOME, -1 );	
- 		SystemCategories = create_category_tree( "SYSTEM", SYSTEM_APPS_PATH, SYSTEM_ICONS_PATH, ASCT_ExcludeGNOME|ASCT_ExcludeKDE, -1 );	
+ 		OtherCategories = create_category_tree( "OTHER", OTHER_APPS_PATH, OTHER_ICONS_PATH, ASCT_ExcludeGNOME|ASCT_ExcludeKDE, -1 );	
 	}	 
 
 	CombinedCategories = create_category_tree( "", NULL, NULL, 0, -1 );	 
@@ -570,7 +591,7 @@ ReloadCategories(Bool cached)
 		add_category_tree_subtree( AfterStepCategories   , StandardCategories );
 		add_category_tree_subtree( KDECategories   , StandardCategories );
  		add_category_tree_subtree( GNOMECategories , StandardCategories );
- 		add_category_tree_subtree( SystemCategories, StandardCategories );
+ 		add_category_tree_subtree( OtherCategories , StandardCategories );
 	}
  	load_category_tree( AfterStepCategories    );
 	SHOW_TIME("AfterStep categories",started);
@@ -578,8 +599,8 @@ ReloadCategories(Bool cached)
 	SHOW_TIME("KDE categories",started);
 	load_category_tree( GNOMECategories  );
 	SHOW_TIME("GNOME categories",started);
- 	load_category_tree( SystemCategories );
-	SHOW_TIME("System categories",started);
+ 	load_category_tree( OtherCategories );
+	SHOW_TIME("Other categories",started);
 
 	LOCAL_DEBUG_OUT( "@ Building up Combined: @@@@@@@@@@@@@@@@@@@@@@@@@@@@%s","" );
 	
@@ -587,7 +608,7 @@ ReloadCategories(Bool cached)
 	add_category_tree_subtree( CombinedCategories, AfterStepCategories      );
 	add_category_tree_subtree( CombinedCategories, KDECategories      );
  	add_category_tree_subtree( CombinedCategories, GNOMECategories    );
- 	add_category_tree_subtree( CombinedCategories, SystemCategories   );
+ 	add_category_tree_subtree( CombinedCategories, OtherCategories   );
 	
 	SHOW_TIME(__FUNCTION__,started);
 }	 
@@ -650,8 +671,8 @@ main( int argc, char ** argv )
 		print_category_tree2( KDECategories, NULL );
 		fprintf( stderr, "#GNOME:    ####################################################\n" );
 		print_category_tree2( GNOMECategories, NULL );
-		fprintf( stderr, "#SYSTEM:   ####################################################\n" );
-		print_category_tree2( SystemCategories, NULL );
+		fprintf( stderr, "#OTHER:   ####################################################\n" );
+		print_category_tree2( OtherCategories, NULL );
 		fprintf( stderr, "#Combined: ####################################################\n" );
 		print_category_tree2( CombinedCategories, NULL );
 		fprintf( stderr, "#####################################################\n" );
@@ -702,8 +723,8 @@ main( int argc, char ** argv )
 	print_category_tree2( KDECategories, NULL );
 	fprintf( stderr, "#GNOME: ####################################################\n" );
 	print_category_tree2( GNOMECategories, NULL );
-	fprintf( stderr, "#SYSTEM: ####################################################\n" );
-	print_category_tree2( SystemCategories, NULL );
+	fprintf( stderr, "#OTHER: ####################################################\n" );
+	print_category_tree2( OtherCategories, NULL );
 	fprintf( stderr, "#Combined: ####################################################\n" );
 	print_category_tree2( CombinedCategories, NULL );
 	fprintf( stderr, "#####################################################\n" );
