@@ -35,6 +35,7 @@
 #include "session.h"
 #include "balloon.h"
 #include "mystyle.h"
+#include "mylook.h"
 #include "wmprops.h"
 #include "desktop_category.h"
 #include "../libAfterImage/xpm.h"
@@ -97,7 +98,7 @@ struct ASCategoryTree *StandardCategories = NULL ;
 struct ASCategoryTree *AfterStepCategories = NULL ;
 struct ASCategoryTree *KDECategories = NULL ;
 struct ASCategoryTree *GNOMECategories = NULL ;
-struct ASCategoryTree *SystemCategories = NULL ;
+struct ASCategoryTree *OtherCategories = NULL ;
 struct ASCategoryTree *CombinedCategories = NULL ;
 
 
@@ -122,7 +123,7 @@ TermDef       FuncTerms[F_FUNCTIONS_NUM + 1] = {
 	FUNC_TERM2 (USES_NUMVALS, "CursorMove", F_MOVECURSOR),	/* CursorMove horiz vert */
 	FUNC_TERM2 (NEED_WINIFNAME, "WarpFore", F_WARP_F),	/* WarpFore ["name" window_name] */
 	FUNC_TERM2 (NEED_WINIFNAME, "WarpBack", F_WARP_B),	/* WarpBack ["name" window_name] */
-	FUNC_TERM2 (NEED_NAME | NEED_WINDOW, "Wait", F_WAIT),	/* Wait      "name" window_name  */
+	FUNC_TERM2 (NEED_NAME | NEED_CMD, "Wait", F_WAIT),	/* Wait      "name" attributes  */
 	FUNC_TERM2 (USES_NUMVALS, "Desk", F_DESK),	/* Desk arg1 [arg2] */
 	FUNC_TERM2 (USES_NUMVALS, "GotoDeskViewport", F_GOTO_DESKVIEWPORT),	/* GotoDeskViewport DESK+VX+VY */
 #ifndef NO_WINDOWLIST
@@ -166,8 +167,11 @@ TermDef       FuncTerms[F_FUNCTIONS_NUM + 1] = {
 	FUNC_TERM2 (TF_SYNTAX_TERMINATOR, "EndFunction", F_ENDFUNC),
 	FUNC_TERM2 (TF_SYNTAX_TERMINATOR, "EndPopup", F_ENDPOPUP),
 	FUNC_TERM ("TakeScreenShot", F_TAKE_SCREENSHOT),
-	FUNC_TERM2 (NEED_NAME | NEED_CMD, "Test", F_Test),
 
+	FUNC_TERM2 (NEED_CMD, "Set", F_SET),	/* Set "name" <variable>=<value> */
+
+	FUNC_TERM2 (NEED_NAME | NEED_CMD, "Test", F_Test),
+	
 	/* this functions require window as aparameter */
 	FUNC_TERM ("&nonsense&", F_WINDOW_FUNC_START),	/* not really a command */
 	FUNC_TERM2 (USES_NUMVALS, "Move", F_MOVE),	/* Move     ["name"] [whereX whereY] */
@@ -328,7 +332,7 @@ CommandLineOpts as_standard_cmdl_options[STANDARD_CMDL_OPTS_NUM] =
 /*17*/{"l", "log","Save all output into the file", "(instead of printing it to console)",
                                                            handler_set_string, &(as_app_args.log_file), 0, CMO_HasArgs },
 /*18*/{"L", "locale","Set language locale", "to be used while displaying text",
-                                                           handler_set_string, &(as_app_args.locale), 0, CMO_HasArgs },
+                                                           handler_set_dup_string, &(as_app_args.locale), 0, CMO_HasArgs },
 /*19*/{NULL, "myname","Overrides module name", "will be used while parsing config files\nand reporting to AfterStep",
                                                            handler_set_string, &(MyName), 0, CMO_HasArgs },
 /*20*/{NULL, "geometry","Overrides module's geometry", NULL,
@@ -439,6 +443,18 @@ void  handler_set_string( char *argv, void *trg, long param )
     if( argv )
         *s = argv;
 }
+
+void  handler_set_dup_string( char *argv, void *trg, long param )
+{
+    register char **s = trg;
+    if( argv )
+	{
+    	if( *s ) 
+			free( *s );
+	    *s = mystrdup(argv);
+	}
+}
+
 void  handler_set_int( char *argv, void *trg, long param )
 {
     register int *i = trg ;
@@ -561,6 +577,7 @@ InitMyApp (  const char *app_class, int argc, char **argv, void (*version_func)
 
 
     ASDefaultScr = safecalloc(1, sizeof(ScreenInfo));
+	init_ScreenInfo(ASDefaultScr);
 
     if( argc > 0 && argv )
     {
@@ -593,15 +610,18 @@ InitMyApp (  const char *app_class, int argc, char **argv, void (*version_func)
         }
     }
 
-    fd_width = get_fd_width ();
-
-    if (FuncSyntax.term_hash == NULL)
-		PrepareSyntax (&FuncSyntax);
     set_output_threshold( as_app_args.verbosity_level );
     if(as_app_args.log_file)
 		if( freopen( as_app_args.log_file, get_flags( as_app_args.flags, ASS_Restarting)?"a":"w", stderr ) == NULL )
 	    	show_system_error( "failed to redirect output into file \"%s\"", as_app_args.log_file );
 
+
+    fd_width = get_fd_width ();
+
+    if (FuncSyntax.term_hash == NULL)
+		PrepareSyntax (&FuncSyntax);
+	if( as_app_args.locale == NULL ) 
+		as_app_args.locale = mystrdup("");
 	if( as_app_args.locale && strlen(as_app_args.locale) > 0)
 	{
 		as_set_charset( parse_charset_name( as_app_args.locale ));
@@ -623,14 +643,16 @@ InitMyApp (  const char *app_class, int argc, char **argv, void (*version_func)
     trace_enable_function(as_app_args.trace_calls);
 #endif
 
-	asxml_var_insert("icon.button.width", 64);
-	asxml_var_insert("icon.button.height", 64);
-	asxml_var_insert("icon.width", 48);
-	asxml_var_insert("icon.height", 48);
-	asxml_var_insert("minipixmap.width", 24);
-	asxml_var_insert("minipixmap.height", 24);
-	asxml_var_insert("title.font.size", 14);
-	asxml_var_insert("menu.font.size", 16);
+	asxml_var_insert(ASXMLVAR_IconButtonWidth, 64);
+	asxml_var_insert(ASXMLVAR_IconButtonHeight, 64);
+	asxml_var_insert(ASXMLVAR_IconWidth, 48);
+	asxml_var_insert(ASXMLVAR_IconHeight, 48);
+	asxml_var_insert(ASXMLVAR_MinipixmapWidth, 24);
+	asxml_var_insert(ASXMLVAR_MinipixmapHeight, 24);
+	asxml_var_insert(ASXMLVAR_TitleFontSize, 14);
+	asxml_var_insert(ASXMLVAR_MenuFontSize, 16);
+	asxml_var_insert(ASXMLVAR_MenuShowMinipixmaps, 1);
+	asxml_var_insert(ASXMLVAR_MenuShowUnavailable, 1);
 
 }
 
@@ -798,8 +820,9 @@ make_default_environment()
 	for( i = 0 ; i < ASTool_Count ; ++i )
 		e->tool_command[i] = as_get_default_tool(i);	 
 
-	e->gtkrc_path = make_session_rc_file(Session, GTKRC_FILE);
-  	e->gtkrc20_path = make_session_rc_file(Session, GTKRC20_FILE) ;
+	/* by default - don't do overwrite gtkrc files so to not aggrave people */
+	e->gtkrc_path = NULL ;  /* make_session_rc_file(Session, GTKRC_FILE); */
+  	e->gtkrc20_path = NULL ; /* make_session_rc_file(Session, GTKRC20_FILE) ; */
 
 	return e;
 }
@@ -869,9 +892,9 @@ name2desktop_category( const char *name, ASCategoryTree **tree_return )
 	{	
 		ct = GNOMECategories ; 
 		offset = 6 ; 
-	}else if( !mystrncasecmp (name, "SYSTEM:", 7) )
+	}else if( !mystrncasecmp (name, "OTHER:", 7) )
 	{	
-		ct = SystemCategories ;
+		ct = OtherCategories ;
 		offset = 7 ; 
 	}else if( !mystrncasecmp (name, "COMBINED:", 9) )
 	{	
@@ -899,26 +922,38 @@ InitSession()
 	}
 }
 
+void
+free_as_app_args()
+{
+	int i;
+	for( i = 0 ; i < as_app_args.saved_argc ; ++i ) 
+		if( as_app_args.saved_argv[i] )
+			free( as_app_args.saved_argv[i] );
+    free( as_app_args.saved_argv );
+	as_app_args.saved_argv = NULL ;
 
+	destroy_string( &(as_app_args.locale) );
+
+}
 
 void
 FreeMyAppResources()
 {
-	int i;
-    balloon_init (True);
+	cleanup_default_balloons();
 	destroy_asdatabase();
     mystyle_destroy_all();
+    mylook_init( &(ASDefaultScr->Look), True, ASFLAGS_EVERYTHING );
     destroy_image_manager( ASDefaultScr->image_manager, False );
     destroy_font_manager( ASDefaultScr->font_manager, False );
     clientprops_cleanup ();
     destroy_wmprops (ASDefaultScr->wmprops, False);
     wmprops_cleanup ();
     free_func_hash();
+	flush_keyword_ids();
     purge_asimage_registry();
 	asxml_var_cleanup();
 	custom_color_cleanup();
     build_xpm_colormap( NULL );
-    flush_ashash_memory_pool();
     destroy_screen_gcs(ASDefaultScr);
 	if( ASDefaultScr->RootImage ) 
 	{	
@@ -926,12 +961,7 @@ FreeMyAppResources()
 		ASDefaultScr->RootImage = NULL ;
 	}
 	destroy_asvisual( ASDefaultScr->asv, False );
-    flush_asbidirlist_memory_pool();
-	for( i = 0 ; i < as_app_args.saved_argc ; ++i ) 
-		if( as_app_args.saved_argv[i] )
-			free( as_app_args.saved_argv[i] );
-    free( as_app_args.saved_argv );
-	
+	free_as_app_args();
     destroy_assession( Session );
 	Session = NULL ;
 	destroy_asenvironment( &Environment );
@@ -941,7 +971,9 @@ FreeMyAppResources()
 #endif
 	free( ASDefaultScr );
 	flush_default_asstorage();
-
+    flush_asbidirlist_memory_pool();
+	flush_ashash_memory_pool();
+	
 }
 
 
