@@ -50,6 +50,8 @@ typedef struct ASInternalWindow
     void (*on_hilite_changed)( struct ASInternalWindow *asiw, ASMagic *data, Bool focused );
     /* ButtonPress/Release event on one of the contexts : */
     void (*on_pressure_changed)( struct ASInternalWindow *asiw, int pressed_context );
+    /* Mouse wheel scrolling event : */
+    void (*on_scroll_event)( struct ASInternalWindow *asiw, struct ASEvent *event );
     /* Motion notify : */
     void (*on_pointer_event)( struct ASInternalWindow *asiw, struct ASEvent *event );
     /* KeyPress/Release : */
@@ -116,6 +118,8 @@ typedef struct ASWindow
 #define ASWIN_CLEAR_FLAGS(t,f) 	clear_flags((t)->status->flags,(f))
 #define ASWIN_FUNC_MASK(t)  ((t)->hints->function_mask)
 
+#define ASWIN_FOCUSABLE(asw)  (ASWIN_HFLAGS(asw, AS_AcceptsFocus) || get_flags((asw)->hints->protocols, AS_DoesWmTakeFocus))
+
 #define IsBtnDisabled(t,b)  get_flags((t)->hints->disabled_buttons,(0x01<<(b)))
 #define IsBtnEnabled(t,b)   (!get_flags((t)->hints->disabled_buttons,(0x01<<(b))))
 #define DisableBtn(t,b)  	clear_flags((t)->hints->disabled_buttons,(0x01<<(b)))
@@ -347,6 +351,10 @@ extern ASFlagType    AfterStepState;              /* see ASS_ flags above */
 extern struct ASDatabase *Database;
 extern ASHashTable       *ComplexFunctions;
 
+extern ASBalloonState *MenuBalloons ; 
+extern ASBalloonState *TitlebarBalloons ; 
+
+
 /* global variables for Look values : */
 extern unsigned long XORvalue;
 extern int           RubberBand;
@@ -454,6 +462,7 @@ void on_window_moveresize( ASWindow *asw, Window w );
 void on_icon_changed( ASWindow *asw );
 void on_window_title_changed( ASWindow *asw, Bool update_display );
 void on_window_hints_changed( ASWindow *asw );
+void on_window_opacity_changed( ASWindow *asw );
 void on_window_status_changed( ASWindow *asw, Bool update_display, Bool reconfigured );
 void on_window_hilite_changed( ASWindow *asw, Bool focused );
 void on_window_pressure_changed( ASWindow *asw, int pressed_context );
@@ -573,6 +582,7 @@ void ExecuteFunctionForClient(struct FunctionData *data, Window client);
 void ExecuteFunctionExt (struct FunctionData *data, struct ASEvent *event, int module, Bool defered);
 /* execute all the scheduled functions from the queue */
 void ExecutePendingFunctions();
+void DestroyPendingFunctionsQueue();
 /* non-window specific, non-defferrable functions are run : */
 void ExecuteBatch ( ComplexFunction *batch );
 
@@ -680,6 +690,7 @@ void change_desktop_background( int desk );
 void HandleBackgroundRequest( struct ASEvent *event );
 Bool is_background_xfer_ximage( unsigned long id );
 void stop_all_background_xfer();
+void release_all_old_background( Bool forget );
 
 
 
