@@ -55,6 +55,163 @@
 #include "../../libAfterConf/afterconf.h"
 
 
+typedef struct AfterStepConfig
+{
+	ASModuleConfig asmodule_config;
+	ASFlagType	flags ;
+	ASFlagType	set_flags ;
+
+}AfterStepConfig;
+
+#define AS_AFTERSTEP_CONFIG(p) AS_MODULE_CONFIG_TYPED(p,CONFIG_AfterStep_ID,AfterStepConfig)
+
+
+static void
+InitAfterStepConfig (ASModuleConfig *asm_config, Bool free_resources)
+{
+	AfterStepConfig *config = AS_AFTERSTEP_CONFIG(asm_config);
+	if( config ) 
+	{
+		/* TODO */
+		if( free_resources ) 
+		{
+		}
+	}
+}
+
+void
+AfterStep_fs2config( ASModuleConfig *asmodule_config, FreeStorageElem *Storage )
+{
+	FreeStorageElem *pCurr;
+	ConfigItem    item;
+	AfterStepConfig *config = AS_AFTERSTEP_CONFIG(asmodule_config) ;
+	
+	if( config == NULL ) 
+		return ; 
+	
+	item.memory = NULL;
+    for (pCurr = Storage; pCurr; pCurr = pCurr->next)
+	{
+		if (pCurr->term == NULL)
+			continue;
+
+		if (pCurr->term->type == TT_FLAG)
+        {
+        }else
+		{
+			if (!ReadConfigItem (&item, pCurr))
+				continue;
+
+			switch (pCurr->term->id)
+			{
+		        default:
+        		    item.ok_to_free = 1;
+			}
+		}
+	}
+	
+	ReadConfigItem (&item, NULL);
+}
+
+void
+MergeAfterStepOptions ( ASModuleConfig *asm_to, ASModuleConfig *asm_from)
+{
+    int i ;
+    START_TIME(option_time);
+
+	AfterStepConfig *to = AS_AFTERSTEP_CONFIG(asm_to);
+	AfterStepConfig *from = AS_AFTERSTEP_CONFIG(asm_from);
+	if( to && from )
+	{
+
+    	/* Need to merge new config with what we have already :*/
+    	/* now lets check the config sanity : */
+    	/* mixing set and default flags : */
+    	ASCF_MERGE_FLAGS(to,from);
+
+	}
+    SHOW_TIME("to parsing",option_time);
+}
+
+
+flag_options_xref AfterStepConfigFlags[] = {
+/*	ASCF_DEFINE_MODULE_FLAG_XREF(WINLIST,FillRowsFirst,WinListConfig), */
+    {0, 0, 0}
+};
+
+
+int AfterStepBalloons[] = { TITLE_BALLOON_ID_START, MENU_BALLOON_ID_START, 0 };
+
+static ASModuleConfigClass _afterstep_config_class = 
+{	CONFIG_AfterStep_ID,
+ 	ASMC_HandlePublicLookOptions|
+	ASMC_HandlePublicFeelOptions
+	/* |ASMC_HandleLookMyStyles */,
+	sizeof(AfterStepConfig),
+ 	"afterstep",
+ 	InitAfterStepConfig,
+	AfterStep_fs2config,
+	MergeAfterStepOptions,
+	&AfterStepSyntax,
+	&LookSyntax,
+	&FeelSyntax,
+	AfterStepConfigFlags,
+	offsetof(AfterStepConfig,set_flags),
+	
+	AfterStepBalloons
+ };
+ 
+ASModuleConfigClass *AfterStepConfigClass = &_afterstep_config_class;
+
+
+void 
+ReloadConfig(ASFlagType what)
+{
+	ASBalloonLook ballon_look ; 
+
+	ASModuleConfig *config = parse_asmodule_config_all( AfterStepConfigClass );
+
+	/* apply it  */
+	Print_balloonConfig (config->balloon_configs[0] );
+    balloon_config2look( &Scr.Look, &ballon_look, config->balloon_configs[0], "TitleButtonBalloon" );
+    set_balloon_state_look( TitlebarBalloons, &ballon_look );
+	Print_balloonConfig (config->balloon_configs[1] );
+    balloon_config2look( &Scr.Look, &ballon_look, config->balloon_configs[1], "MenuBalloon" );
+	set_balloon_state_look( MenuBalloons,  &ballon_look );
+	
+	
+	destroy_ASModule_config( config );
+}
+
+#ifdef AFTERSTEP_CONFIG_TEST
+
+ASBalloonState *MenuBalloons = NULL ; 
+ASBalloonState *TitlebarBalloons = NULL ; 
+
+int main(int argc, char **argv )
+{
+
+    ASImageManager  *old_image_manager = NULL ;
+    ASFontManager   *old_font_manager  = NULL ;
+    InitMyApp( CLASS_AFTERSTEP, argc, argv, NULL, NULL, 0);
+	LinkAfterStepConfig();
+    if( ConnectX( ASDefaultScr, 0 ) < 0  )
+	{
+		show_error( "Hostile X server encountered - unable to proceed :-(");
+		return 1;/* failed to accure window management selection - other wm is running */
+	}
+	InitSession();
+	MenuBalloons = create_balloon_state(); 
+	TitlebarBalloons = create_balloon_state(); 
+	ReloadASEnvironment( &old_image_manager, &old_font_manager, NULL, True, True );
+	LoadColorScheme();
+	ReloadConfig(0xFFFFFFFF);
+
+}
+
+#else
+
+
 /* old look auxilary variables : */
 static MyFont StdFont    = {NULL};         /* font structure */
 static MyFont WindowFont = {NULL};      /* font structure for window titles */
@@ -90,7 +247,8 @@ static MyStyleDefinition *MyStyleList = NULL ;
 static MyFrameDefinition *MyFrameList = NULL ;
 static MyFrameDefinition *LegacyFrameDef = NULL ;
 
-static balloonConfig BalloonConfig = {0, 0, 0, 0, 0, 0, NULL };
+static balloonConfig BalloonConfig = {0, 0, 0, 0, 0, 0, 0, NULL, 0, 0 };
+static balloonConfig MenuBalloonConfig = {0, 0, 0, 0, 0, 0, 0, NULL, 0, 0 };
 
 static char         *MSWindowName[BACK_STYLES] = {NULL};
 static char         *MSMenuName[MENU_BACK_STYLES] = {NULL };
@@ -270,6 +428,7 @@ struct config main_config[] = {
     {"TitlebarNoPush"					, SetLookFlag, (char **)TitlebarNoPush, NULL},
     {"TextureMenuItemsIndividually"		, SetLookFlag, (char **)TxtrMenuItmInd,NULL},
     {"MenuMiniPixmaps"					, SetLookFlag, (char **)MenuMiniPixmaps, NULL},
+	{"MenuShowUnavailable"				, SetLookFlag, (char **)MenuShowUnavailable, NULL },
 	{"TitleTextAlign"					, SetInts, (char **)&TmpLook.TitleTextAlign, &dummy},
     {"TitleButtonSpacingLeft"			, SetInts, (char **)&TmpLook.TitleButtonSpacing[0], &dummy},
     {"TitleButtonSpacingRight"			, SetInts, (char **)&TmpLook.TitleButtonSpacing[1], &dummy},
@@ -302,6 +461,15 @@ struct config main_config[] = {
     {"MenuItemCompositionMethod"		, SetInts, (char **)&TmpLook.menu_icm, &dummy},
     {"MenuHiliteCompositionMethod"		, SetInts, (char **)&TmpLook.menu_hcm, &dummy},
     {"MenuStippleCompositionMethod"		, SetInts, (char **)&TmpLook.menu_scm, &dummy},
+    {"MenuBalloonBorderHilite"			, bevel_parse, (char**)"afterstep", (int*)&(MenuBalloonConfig.BorderHilite)},
+    {"MenuBalloonXOffset"				, SetInts, (char**)&(MenuBalloonConfig.XOffset), NULL},
+    {"MenuBalloonYOffset"				, SetInts, (char**)&(MenuBalloonConfig.YOffset), NULL},
+    {"MenuBalloonDelay"					, SetInts, (char**)&(MenuBalloonConfig.Delay), NULL},
+    {"MenuBalloonCloseDelay"			, SetInts, (char**)&(MenuBalloonConfig.CloseDelay), NULL},
+    {"MenuBalloonStyle"					, assign_string,   &(MenuBalloonConfig.Style), NULL},
+    {"MenuBalloonTextPaddingX"			, SetInts, (char**)&(MenuBalloonConfig.TextPaddingX), NULL},
+    {"MenuBalloonTextPaddingY"			, SetInts, (char**)&(MenuBalloonConfig.TextPaddingY), NULL},
+    {"MenuBalloons"						, SetFlag2, (char**)BALLOON_USED, (int*)&(MenuBalloonConfig.set_flags)},
     {"ShadeAnimationSteps"				, SetInts, (char **)&TmpFeel.ShadeAnimationSteps, (int *)&dummy},
     {"TitleButtonBalloonBorderHilite"	, bevel_parse, (char**)"afterstep", (int*)&(BalloonConfig.BorderHilite)},
     {"TitleButtonBalloonXOffset"		, SetInts, (char**)&(BalloonConfig.XOffset), NULL},
@@ -508,9 +676,10 @@ void
 merge_old_look_variables (MyLook *look)
 {
     char         *button_style_names[BACK_STYLES] = 
-{AS_ICON_TITLE_MYSTYLE, 
+													{AS_ICON_TITLE_MYSTYLE, 
 													 AS_ICON_TITLE_UNFOCUS_MYSTYLE, 
 													 AS_ICON_TITLE_STICKY_MYSTYLE, 
+													 NULL,
 													 "ButtonTitleDefault" };
     MyStyle      *button_styles[BACK_STYLES];
     int i ;
@@ -546,20 +715,21 @@ merge_old_look_variables (MyLook *look)
     if (TitleTextType != 0)
 	{
         for( i = 0 ; i < BACK_STYLES ; ++i )
-            if (!get_flags(look->MSWindow[i]->set_flags, F_TEXTSTYLE))
-            {
-                set_flags(look->MSWindow[i]->text_style, TitleTextType);
-                set_flags(look->MSWindow[i]->user_flags, F_TEXTSTYLE);
-                set_flags(look->MSWindow[i]->set_flags, F_TEXTSTYLE);
-            }
+			if( look->MSWindow[i] )
+				if (!get_flags(look->MSWindow[i]->set_flags, F_TEXTSTYLE))
+            	{
+                	set_flags(look->MSWindow[i]->text_style, TitleTextType);
+                	set_flags(look->MSWindow[i]->user_flags, F_TEXTSTYLE);
+                	set_flags(look->MSWindow[i]->set_flags, F_TEXTSTYLE);
+            	}
     }
 	/* the colors */
 	/* for black and white - ignore user choices */
 	/* for color - accept user choices */
 	if (Scr.d_depth > 1)
 	{
-        int wtype[BACK_STYLES];
-        int mtype[MENU_BACK_STYLES];
+        int wtype[BACK_STYLES] = {0};
+        int mtype[MENU_BACK_STYLES] = {0};
 
         for( i = 0 ; i < BACK_STYLES ; ++i )
             wtype[i] = -1 ;
@@ -657,6 +827,7 @@ void
 ApplyFeel( ASFeel *feel )
 {
     check_screen_panframes(ASDefaultScr);
+	
 }
 
 /*
@@ -747,11 +918,6 @@ merge_look( MyLook *to, MyLook *from )
     to->minipixmap_width  = (from->minipixmap_width == 0)? 24 : from->minipixmap_width ; 
 	to->minipixmap_height = (from->minipixmap_height == 0)?to->minipixmap_width:from->minipixmap_height; 
 	
-	asxml_var_insert("icon.button.width", to->ButtonWidth);
-	asxml_var_insert("icon.button.height", to->ButtonHeight);
-
-	asxml_var_insert("minipixmap.width", to->minipixmap_width);
-	asxml_var_insert("minipixmap.height", to->minipixmap_height);
 
 	to->DefaultFrameName = from->DefaultFrameName ; 
 
@@ -769,7 +935,7 @@ void
 make_styles (MyLook *look)
 {
 /* make sure the globals are defined */
-    char *style_names[BACK_STYLES] = { "default", "FWindow", "UWindow", "SWindow" };
+    char *style_names[BACK_STYLES] = { "FWindow", "UWindow", "SWindow", NULL, "default"  };
     char *menu_style_names[MENU_BACK_STYLES] = { "MenuTitle", "MenuItem", "MenuHilite", "MenuStipple", "MenuSubItem", "MenuHiTitle" };
     int i ;
 
@@ -779,7 +945,7 @@ make_styles (MyLook *look)
     if (look->MSWindow[BACK_DEFAULT] == NULL)
         look->MSWindow[BACK_DEFAULT] = mystyle_list_find_or_default (look->styles_list, "default");
     for( i = 0 ; i < BACK_STYLES ; ++i )
-        if (look->MSWindow[i] == NULL)
+        if (look->MSWindow[i] == NULL && style_names[i] )
             look->MSWindow[i] = mystyle_list_new (look->styles_list, style_names[i]);
 
     for( i = 0 ; i < MENU_BACK_STYLES ; ++i )
@@ -1026,7 +1192,6 @@ void
 FixLook( MyLook *look )
 {
     ASFlagType default_title_align = ALIGN_LEFT ;
-	int tbar_font_size = 0 ;
 	int menu_font_size = 0 ;
     int i ;
 #ifdef LOCAL_DEBUG
@@ -1068,19 +1233,14 @@ FixLook( MyLook *look )
     ASSync(False);
 #endif
 
-	for( i = 0 ; i < BACK_STYLES ; ++i ) 
-		if( look->MSWindow[i] )
-			if( look->MSWindow[i]->font.as_font )
-				if( look->MSWindow[i]->font.as_font->max_height > tbar_font_size ) 
-					tbar_font_size = look->MSWindow[i]->font.as_font->max_height ;
-	asxml_var_insert("title.font.size", tbar_font_size);
+	mylook_set_font_size_var (look);
 	
 	for( i = 0 ; i < MENU_BACK_STYLES ; ++i ) 
 		if( look->MSMenu[i] )
 			if( look->MSMenu[i]->font.as_font )
 				if( look->MSMenu[i]->font.as_font->max_height > menu_font_size ) 
 					menu_font_size = look->MSMenu[i]->font.as_font->max_height ;
-	asxml_var_insert("menu.font.size", menu_font_size);
+	asxml_var_insert(ASXMLVAR_MenuFontSize, menu_font_size);
 
 
     mystyle_list_set_property (Scr.wmprops, look->styles_list);
@@ -1168,17 +1328,6 @@ FixLook( MyLook *look )
         }
     }
 
-#ifdef LOCAL_DEBUG
-    LOCAL_DEBUG_OUT( "syncing %s","");
-    ASSync(False);
-#endif
-
-#if defined(LOCAL_DEBUG) && !defined(NO_DEBUG_OUTPUT)
-    Print_balloonConfig ( &BalloonConfig );
-#endif
-    balloon_config2look( look, &BalloonConfig, "TitleButtonBalloon" );
-    set_balloon_look( look->balloon_look );
-
     /* checking sanity of the move-resize window geometry :*/
     if( (look->resize_move_geometry.flags&(HeightValue|WidthValue)) != (HeightValue|WidthValue))
 	{
@@ -1261,6 +1410,7 @@ FixLook( MyLook *look )
 #endif
 }
 
+
 /*
  * Initialize database variables
  */
@@ -1399,6 +1549,7 @@ advertise_tbar_props()
 		}	 
 
 	set_astbar_props( Scr.wmprops, &props ); 
+	free( props.buttons );
 }
 
 
@@ -1509,11 +1660,15 @@ LoadASConfig (int thisdesktop, ASFlagType what)
             if( (const_configfile = get_session_file (Session, thisdesktop, F_CHANGE_LOOK, False) ) != NULL )
             {
                 InitLook (&Scr.Look, True);
+
 				memset( &TmpLook, 0x00, sizeof(TmpLook));
 				TmpLook.magic = MAGIC_MYLOOK ;
 				InitLook (&TmpLook, False );
+
 				LOCAL_DEBUG_OUT( "desk_anime_tint = %lX", TmpLook.desktop_animation_tint );
                 ParseConfigFile (const_configfile, &tline);
+
+
 				LOCAL_DEBUG_OUT( "desk_anime_tint = %lX", TmpLook.desktop_animation_tint );
                 show_progress("LOOK configuration loaded from \"%s\" ...", const_configfile);
                 display_progress( True, "LOOK configuration loaded from \"%s\".", const_configfile);
@@ -1533,6 +1688,7 @@ LoadASConfig (int thisdesktop, ASFlagType what)
 				}
 #endif
 				merge_look( &Scr.Look, &TmpLook );
+			
             }else
             {
                 show_warning("LOOK configuration file cannot be found!");
@@ -1594,23 +1750,6 @@ LoadASConfig (int thisdesktop, ASFlagType what)
                 clear_flags(what, PARSE_FEEL_CONFIG);
             }
         }
-        if (get_flags(what, PARSE_LOOK_CONFIG|PARSE_FEEL_CONFIG))
-		{
-            if( (const_configfile = get_session_file (Session, thisdesktop, F_CHANGE_THEME, False) ) != NULL )
-            {
-                ParseConfigFile (const_configfile, &tline);
-                show_progress("THEME configuration loaded from \"%s\" ...", const_configfile);
-                display_progress( True, "THEME configuration loaded from \"%s\" .", const_configfile);
-                if( (configfile = make_session_data_file  (Session, False, R_OK, THEME_OVERRIDE_FILE, NULL )) != NULL )
-                {
-                    ParseConfigFile (configfile, &tline);
-                    show_progress("THEME OVERRIDES configuration loaded from \"%s\" ...", configfile);
-                    display_progress( True, "THEME OVERRIDES configuration loaded from \"%s\" .", configfile);
-                    free( configfile );
-                }
-            }
-        }
-
         if (get_flags(what, PARSE_DATABASE_CONFIG))
 		{
 			if( !ReloadASDatabase() )
@@ -1627,7 +1766,9 @@ LoadASConfig (int thisdesktop, ASFlagType what)
 	} else
 	{
 		ReloadASEnvironment( &old_image_manager, &old_font_manager, NULL, True, True );
+
 		LoadColorScheme();
+
 		memset( &TmpLook, 0x00, sizeof(TmpLook));
 		InitLook (&TmpLook, False );
 		InitLook (&Scr.Look, True);
@@ -1635,9 +1776,10 @@ LoadASConfig (int thisdesktop, ASFlagType what)
 		InitFeel (&TmpFeel, False );
         InitFeel (&Scr.Feel, True);
         ParseConfigFile (Session->overriding_file, &tline);
-        ReloadASDatabase();
 		merge_look( &Scr.Look, &TmpLook );
 		merge_feel( &Scr.Feel, &TmpFeel );
+
+        ReloadASDatabase();
         show_progress("AfterStep configuration loaded from \"%s\" ...", Session->overriding_file);
         display_progress( True, "AfterStep configuration loaded from \"%s\".", Session->overriding_file);
         what = PARSE_EVERYTHING ;
@@ -1659,11 +1801,23 @@ LoadASConfig (int thisdesktop, ASFlagType what)
 	{
 		check_feel_sanity( &Scr.Feel );
         ApplyFeel( &Scr.Feel );
+		asxml_var_insert(ASXMLVAR_MenuRecentSubmenuItems, Scr.Feel.recent_submenu_items );
 	}
 
     if (get_flags(what, PARSE_LOOK_CONFIG))
     {
         FixLook( &Scr.Look );
+
+		asxml_var_insert(ASXMLVAR_IconButtonWidth, Scr.Look.ButtonWidth);
+		asxml_var_insert(ASXMLVAR_IconButtonHeight, Scr.Look.ButtonHeight);
+
+		asxml_var_insert(ASXMLVAR_MinipixmapWidth, Scr.Look.minipixmap_width);
+		asxml_var_insert(ASXMLVAR_MinipixmapHeight, Scr.Look.minipixmap_height);
+
+		asxml_var_insert(ASXMLVAR_MenuShowMinipixmaps, get_flags(Scr.Look.flags, MenuMiniPixmaps)?1:0);
+		asxml_var_insert(ASXMLVAR_MenuShowUnavailable, get_flags(Scr.Look.flags, MenuShowUnavailable)?1:0);
+		asxml_var_insert(ASXMLVAR_MenuTxtItemsInd,     get_flags(Scr.Look.flags, TxtrMenuItmInd)?1:0);
+
         if( thisdesktop == Scr.CurrentDesk )
 		{
 		    MyBackground *new_back = get_desk_back_or_default( Scr.CurrentDesk, False );
@@ -1676,6 +1830,12 @@ LoadASConfig (int thisdesktop, ASFlagType what)
             change_desktop_background( Scr.CurrentDesk );
 		}
     }
+	
+	if (get_flags(what, PARSE_LOOK_CONFIG|PARSE_FEEL_CONFIG))
+	{
+		ReloadConfig(what);
+    }
+
 
     if( get_flags(what, PARSE_BASE_CONFIG|PARSE_LOOK_CONFIG|PARSE_FEEL_CONFIG))
 	{
@@ -2338,4 +2498,5 @@ match_string (struct config *table, char *text, char *error_msg, FILE * fd)
 		tline_error (error_msg);
 }
 
+#endif
 
